@@ -1,4 +1,6 @@
 from .app import App
+import pyvisflow.core.user_utils
+
 
 app = App()
 
@@ -31,6 +33,7 @@ __all__ = [
     'image_from_file',
     'image_from_url',
     'button',
+    'utils'
 ]
 
 image_from_mpl= app.image_from_mpl
@@ -63,3 +66,6 @@ dataset = app.dataset
 
 config2file = app.config2file
 to_html = app.to_html
+
+utils=pyvisflow.core.user_utils
+
