@@ -1,9 +1,10 @@
 from typing import Union,Dict,List
 from pyvisflow.core.components.components import Component
-from pyvisflow.core.props import TypePropInfo,StrTypePropInfo,SubscriptableTypePropInfo, NumberTypePropInfo, BoolTypePropInfo
+from pyvisflow.core.props import StrTypePropInfo, NumberTypePropInfo, BoolTypePropInfo
 from pyvisflow.models.TComponent import TComponentType
 from pyvisflow.core.props import *
 
+TypePropInfo=Union[StrTypePropInfo,NumberTypePropInfo,BoolTypePropInfo]
 
 class _InputNumber(Component):
     '''
