@@ -3,10 +3,12 @@ from typing import Any, Dict, List, Optional, Union
 from pyvisflow.core.dataset.props import DatasetSeriesPropInfo, ReactiveDatasetPropInfo
 from pyvisflow.core.props import SubscriptableTypePropInfo, StrTypePropInfo
 from pyvisflow.core.props.absProp import AbsPropInfo
+import json
 
 
 from .auto_create._echart import _EChart
-
+from pyvisflow.core.jsCode import JsCode,get_jscode_paths
+from pyvisflow.core.user_utils.common import js_code
 
 class EChart(_EChart):
     def __init__(
@@ -18,16 +20,25 @@ class EChart(_EChart):
             self
             .set_option('series',[])
         )
+        self._functionSettings=[]
 
     @property
     def utils(self, ):
         return Helper(self)
 
+    def mark_json_code(self,option_path:str):
+        self._functionSettings.append(option_path)
+        return self
 
-    def set_option(self, prop: str, data: Any):
+    def set_option(self, prop: str, data: Any or JsCode):
         if not prop.startswith('option.'):
             prop = f'option.{prop}'
         self.set_prop(prop, data)
+
+
+        for path in get_jscode_paths(prop,data):
+            self.mark_json_code(path) 
+
         return self
 
     def set_series(self, idx: int, prop: str, data: Any):
@@ -36,11 +47,23 @@ class EChart(_EChart):
 
     @property
     def clickInfo(self):
-        p = self.get_prop('clickInfo')
-        return SubscriptableTypePropInfo[str, StrTypePropInfo](p)
+        """点击联动属性
+        可以获取用户点击图表上的图形时的相关信息，比如点击柱状图的某个柱子的数据，系列名等信息
 
+        Returns:
+            EventInfoWrapper: 属性包装器
+        """
+        return EventInfoWrapper(self,'clickInfo')
 
+    @property
+    def hoverInfo(self):
+        """悬停联动属性
+        可以获取 鼠标经过图表上的图形时的相关信息，比如经过柱状图的某个柱子的数据，系列名等信息
 
+        Returns:
+            EventInfoWrapper: 属性包装器
+        """
+        return EventInfoWrapper(self,'hoverInfo')
 
 
     def _ex_get_react_data(self):
@@ -51,10 +74,40 @@ class EChart(_EChart):
 
             },
             'clickInfo': {},
+            'hoverInfo':{},
+            'functionSettings':self._functionSettings
         })
         return data
 
 
+class EventInfoWrapper():
+
+    def __init__(self,echart:EChart,info_name:str) -> None:
+        self.__echart=echart
+        self.__clickInfo_prop=self.__echart.get_prop(info_name)
+
+    def __get_click_prop_info(self):
+        return SubscriptableTypePropInfo[str, StrTypePropInfo](self.__clickInfo_prop) 
+
+    @property
+    def name(self):
+        """ 数据名，类目名
+
+        Returns:
+            StrTypePropInfo: value of name
+        """
+        return self.__get_click_prop_info()['name']
+
+    @property
+    def data(self):
+        """传入的原始数据项
+
+        Returns:
+            object: Data Objects
+        """
+        return self.__get_click_prop_info()['data']
+
+
 class Helper():
     def __init__(self, echart: EChart) -> None:
         self._echart = echart
@@ -64,6 +117,64 @@ class Helper():
             self._echart.set_option(key,value)
         return self
 
+    def use_from_json_file(self,path:str):
+        with open('fig.json',encoding='utf8') as f:
+            opts = json.load(f)
+            self.use_from_option_dict(opts)
+            return self
+
+
+
+    def setLastSymbol(self,series_index:int,last:str,others:str):
+        echart = self._echart
+        echart.set_option(f'series[{series_index}].symbol',js_code(f'''
+            (value,p,opt)=>{{
+                const len = opt.series[p.seriesIndex].data.length
+                const lastPoint = p.dataIndex===len-1
+                if(lastPoint){{
+                    return '{last}'
+                }}else{{
+                    return '{others}'
+                }}
+            }}
+        '''))
+
+        echart.set_option('series[0].symbolRotate',js_code('''
+            (value,p,opt,chart)=>{
+                
+                const len = opt.series[p.seriesIndex].data.length
+                const lastPoint = p.dataIndex===len-1
+                if(lastPoint){
+                    const yData = opt.series[p.seriesIndex].data
+                    const xData = opt.xAxis.data
+                    let point1 = chart.convertToPixel({seriesIndex:p.seriesIndex},[xData[len-2],yData[len-2]])
+                    let point2 = chart.convertToPixel({seriesIndex:p.seriesIndex},[xData[len-1],yData[len-1]])
+
+                    /*
+                    point2=[2,yData[len-1]]
+                    point1=[1,yData[len-2]]
+                    */
+
+                    const dist = Math.sqrt(Math.pow(point2[0]-point1[0],2)+Math.pow(point2[1]-point1[1],2))
+
+                    const deg = Math.round(Math.asin((point2[0]-point1[0])/dist) * 180 / Math.PI)
+
+                    if(yData[len-1]>yData[len-2]){
+                        return -deg
+                    }
+
+                    return deg +180
+                    
+                }else{
+                    return 0
+                }
+            }
+        '''))
+
+        return echart
+  
+
+
     def use_pie(self, dataset: ReactiveDatasetPropInfo):
 
         dataset = dataset.rename({0:'name',1:'value'})[['name','value']]
