@@ -1,6 +1,4 @@
 from typing import Union
-from pyvisflow.core.components.components import Component
-from pyvisflow.models.TComponent import TComponentType
 from .auto_create._inputNumber import _InputNumber
 
 
