@@ -1,6 +1,6 @@
 from typing import Dict, Hashable, Any, Optional, Union
 from pyvisflow.core.reactive import Reactive
-from pyvisflow.core.props import TypePropInfo
+from pyvisflow.core.props import TTypePropInfo
 
 
 class Structure(Reactive):
@@ -32,7 +32,7 @@ class Mapping(Structure):
         return self.get_prop('key')
 
     @key.setter
-    def key(self, value: Union[TypePropInfo, str]):
+    def key(self, value: Union[TTypePropInfo, str]):
         self.set_prop('key', value)
 
     # def __getitem__(self, item: str):
