@@ -1,11 +1,14 @@
 import base64
 from datetime import datetime
+from enum import Enum
 from pathlib import Path
 from json import JSONEncoder, dumps
 from functools import partial
 import numpy as np
 import pandas as pd
 
+from pyvisflow.utils.jsonable import Jsonable
+
 _global_id = 0
 
 
@@ -33,6 +36,8 @@ def _nan2None(obj):
         return obj.tolist()
     elif isinstance(obj,datetime):
         return str(obj)
+    elif isinstance(obj,Jsonable):
+        return _nan2None(obj._to_json_dict())
 
     return obj
 
@@ -57,4 +62,16 @@ json_dumps_fn = partial(dumps, cls=_NanConverter)
 def data2html_img_src(data:bytes):
     b64=base64.b64encode(data).decode('utf8')
     value = f'data:image/png;base64,{b64}'
-    return value
\ No newline at end of file
+    return value
+
+
+
+class StrEnum(str, Enum):
+    def __new__(cls, value, *args, **kwargs):
+        return super().__new__(cls, value, *args, **kwargs)
+
+    def __str__(self):
+        return str(self.value)
+
+    def _generate_next_value_(name, *_):
+        return name
\ No newline at end of file
